//pravdepodobnost - statisticka, klasicka, atd.

//statická pravděpodobnost
function [vystup]=statisticka_pr(M,N)
    //vystup...relativní četnost jevu J
    //M...počet pokusů, kdy jev nastoupil
    //N...celkový počet pokusů
    vystup=M/N;
endfunction

//klasická pravděpodobnost
function [vystup]=klasicka_pr(m,n)
    //vystup...pravděpodobnost jevu J
    //m...počet jevů, kdy se splní zadané pravidlo
    //n...počet jevů, které mohou nastoupit
    vystup=m/n
endfunction

//podmíněná pravděpodobnost
function [J1podminenoJ2,J2podminenoJ1]=podminena_pr(J1,J2,n)
    if argn(2)<3 then
        n=size(union(J1,J2),2)
    end
    //J1podminenoJ2...J1|J2
    //J2podminenoJ1...J2|J1
    //J1... vektor hodnot jevu J1
    //J2... vektor hodnot jevu J2
    //n... počet jevů, které mohou nastoupit, pokud není n zadáno, n=J1 U J2
    prunik=intersect(J1,J2); //zjistí, které hodnoty jsou shodné
    pJ1=size(J1,2)/n;        //pravděpodobnost jevu J1
    pJ2=size(J2,2)/n;        //pravděpodobnost jevu J2
    p_pruniku=size(prunik,2)/n;  //pravděpodobnost pruniku
    J1podminenoJ2=p_pruniku/pJ2; //p(J1|J2)
    J2podminenoJ1=p_pruniku/pJ1; //p(J2|J1)
endfunction

//nezavislost jevů
function [vysledek]=nezavislost_jevu(pJ1,pJ2,pJ3,pJ4,pJ5)
    select argn(2)
       case 2 then
           pJ3=1; pJ4=1; pJ5=1;
       case 3 then
           pJ4=1; pJ5=1;
       case 4 then
           pJ5=1;
    end
  //co bude vstupem?
    vysledek=pJ1*pJ2*pJ3*pJ4*pJ5;
endfunction

//uplna pravdepodobnost
function [vysledek]=uplna_pr(pAzaB1,pB1,pAzaB2,pB2,pAzaB3,pB3)
    // pAzaB1 = p(A|B1), pB1=p(B1)
    // pAzaB2 = p(A|B2), pB2=p(B2)
    // pAzaB3 = p(A|B3), pB3=p(B3)    
    if argn(2)<5 then
        pAzaB3=0; pB3=0;
    end
    if argn(2)==3 then
        pB2=1-pB1;
    end
    if argn(2)==5 then
        pB3=1-(pB1+pB2);
    end
    vysledek=pAzaB1*pB1+pAzaB2*pB2+pAzaB3*pB3; //vzoreček ÚP
endfunction



//bayesův vzorec
function [vysledek]=bayesuv_vzorec(PA,pAzaB1,pB1,pAzaB2,pB2,pAzaB3,pB3)
    // pAzaB1 = p(A|B1), pB1=p(B1)
    // pAzaB2 = p(A|B2), pB2=p(B2)
    // pAzaB3 = p(A|B3), pB3=p(B3)    
    UP=uplna_pr(pAzaB1,pB1,pAzaB2,pB2,pAzaB3,pB3) //uplna pravdepodobnost
    select PA
    case 1
        vysledek=(pAzaB1*pB1)/UP;
    case 2
        vysledek=(pAzaB2*pB2)/UP;
    case 3
        vysledek=(pAzaB3*pB3)/UP;        
    end
endfunction


