function [dolni_mez, horni_mez]=z_int (stredni_hodnota,rozptyl,n,strana,alpha)
    //horni_mez ... horní mez intervalu
    //dolni_mez ... dolní mez intervalu
    //stredni_hodnota ... střední hodnota výběru
    //rozptyl ... rozptyl souboru (musi byt zadán)
    //n ... počet prvků výběru/prvky výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==4 then
       alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end

    select strana
    case 'o' then
        z_alpha_2=cdfnor("X",0,1,1-alpha/2,alpha/2);
        horni_mez=stredni_hodnota+z_alpha_2*sqrt(rozptyl)/sqrt(n);
        dolni_mez=stredni_hodnota-z_alpha_2*sqrt(rozptyl)/sqrt(n);
    case 'p' then
        z_alpha_2=cdfnor("X",0,1,1-alpha,alpha);
        horni_mez=stredni_hodnota+z_alpha_2*sqrt(rozptyl)/sqrt(n);
        dolni_mez=-%inf;
    case 'l' then
        z_alpha_2=cdfnor("X",0,1,alpha,1-alpha);
        horni_mez=%inf;
        dolni_mez=stredni_hodnota+z_alpha_2*sqrt(rozptyl)/sqrt(n);
    end

endfunction

function [dolni_mez, horni_mez]=t_int (stredni_hodnota,rozptyl,n,strana,alpha)
    //horni_mez ... horní mez intervalu
    //dolni_mez ... dolní mez intervalu
    //stredni_hodnota ... střední hodnota výběru
    //rozptyl ... rozptyl výběru
    //n ... pocet prvků výběru/prvky výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti

    if argn(2)==4 then
       alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    select strana
    case 'o' then
        t_alpha_2=cdft("T",n-1,1-alpha/2,alpha/2);
        horni_mez=stredni_hodnota+t_alpha_2*sqrt(rozptyl)/sqrt(n);
        dolni_mez=stredni_hodnota-t_alpha_2*sqrt(rozptyl)/sqrt(n);
    case 'p' then
        t_alpha_2=cdfnor("X",0,1,1-alpha,alpha);
        horni_mez=stredni_hodnota+t_alpha_2*sqrt(rozptyl)/sqrt(n);
        dolni_mez=-%inf;
    case 'l' then
        t_alpha_2=cdfnor("X",0,1,alpha,1-alpha);
        horni_mez=%inf;
        dolni_mez=stredni_hodnota+t_alpha_2*sqrt(rozptyl)/sqrt(n);
    end   
endfunction

function [dolni_mez, horni_mez]=prop_int(p,n,strana,alpha)
    //horni_mez ... horní mez intervalu
    //dolni_mez ... dolní mez intervalu
    //p ... pravděpodobnost úspěchu nebo počet úspěchů ve výběru
    //n ... pocet prvků výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==3 then
       alpha=0.05;
    end    
    if p>1 then
        prav=p/n;
    else
        prav=p;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    select strana
    case 'o' then
        z_alpha_2=cdfnor("X",0,1,1-alpha/2,alpha/2);
        horni_mez=prav+sqrt(prav*(1-prav)/n)*z_alpha_2;
        dolni_mez=prav-sqrt(prav*(1-prav)/n)*z_alpha_2;
    case 'p' then
        z_alpha_2=cdfnor("X",0,1,1-alpha,alpha);
        horni_mez=prav+sqrt(prav*(1-prav)/n)*z_alpha_2;
        dolni_mez=0;
    case 'l' then
        z_alpha_2=cdfnor("X",0,1,alpha,1-alpha);
        horni_mez=1;
        dolni_mez=prav-sqrt(prav*(1-prav)/n)*z_alpha_2;
    end
endfunction

function [dolni_mez, horni_mez]=var_int(rozptyl,n,strana,alpha)
    //horni_mez ... horní mez intervalu
    //dolni_mez ... dolní mez intervalu
    //stredni_hodnota ... střední hodnota souboru
    //rozptyl ... rozptyl výběru
    //n ... počet prvků výběru / vektor
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti    
    if argn(2)==3 then
       alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    select strana
    case 'o' then
        hm_chi_alpha_2=cdfchi("X",n-1,alpha/2,1-alpha/2);
        dm_chi_alpha_2=cdfchi("X",n-1,1-alpha/2,alpha/2);
        horni_mez=(n-1)*rozptyl/hm_chi_alpha_2;
        dolni_mez=(n-1)*rozptyl/dm_chi_alpha_2;
    case 'p' then
        hm_chi_alpha_2=cdfchi("X",n-1,alpha,1-alpha);
        horni_mez=(n-1)*rozptyl/hm_chi_alpha_2;
        dolni_mez=0;
    case 'l' then
        dm_chi_alpha_2=cdfchi("X",n-1,1-alpha,alpha);
        horni_mez=%inf;
        dolni_mez=(n-1)*rozptyl/dm_chi_alpha_2;
    end
    
endfunction

