//chi kvadrat test dobre shody
function [p_hodnota,T,chi_alpha]=chisquare_test(O,E,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //O ... pozorované četnosti
    //E ... očekávané četnosti
    //alpha ... hladina významnosti
    if argn(2)==2 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    O=O(:)';
    E=E(:)';
    n=size(O,2);
    
    T=sum((O-E).^2 ./E);
    [P,Q]=cdfchi("PQ",T,n-1)
    p_hodnota=Q;
    hm_chi_alpha=cdfchi("X",n-1,1-alpha,alpha);
    chi_alpha=[0,hm_chi_alpha]
endfunction

//chi kvadrat test nezavislosti
function [p_hodnota,T,chi_alpha]=chisquare_test_i(KT,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //KT ... kontingenční tabulka
    //alpha ... hladina významnosti
    if argn(2)==1 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    [r,s]=size(KT);
    pravdepodobnost_KT=KT/sum(KT);
    pravdepodobnost_O=sum(pravdepodobnost_KT,2)*sum(pravdepodobnost_KT,1);
    O=pravdepodobnost_O*sum(KT);
    
    T=sum((KT-O).^2 ./O);  
    Df=(r-1)*(s-1);
    [P,Q]=cdfchi("PQ",T,Df)
    p_hodnota=Q;
    hm_chi_alpha=cdfchi("X",Df,1-alpha,alpha);
    chi_alpha=[0,hm_chi_alpha]
endfunction


//znaménkový test
function [p_hodnota,T,z_alpha]=sign_test(X,Y,strana,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //X ... náhodný výběr č. 1
    //Y ... náhodný výběr č. 2 / medián
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==3 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    X=X(:)';
    Y=Y(:)';
    
    if size(Y,2)==1 then
        disp('medianovy test')
    end
    n=size(X,2);
    b=sum(X>Y);
    T=((2*b)-n)/sqrt(n);
    [P,Q]=cdfnor("PQ",T,0,1);
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;
        z_alpha=cdfnor("X",0,1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        z_alpha=cdfnor("X",0,1,1-alpha,alpha);
    case 'l' then
        z_alpha=cdfnor("X",0,1,alpha,1-alpha);
        p_hodnota=P;
    end
endfunction
    
//pořadový test nezávislosti
function [p_hodnota,T,z_alpha]=ordinal_test(x,alpha) 
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny 
    //z_alpha ... kritická hodnota
    //X ... náhodný výběr
    //alpha ... hladina významnosti
    if argn(2)==1 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    x=x(:)';
    me_x=median(x);
    n=size(x,2);
    rozdil=x-me_x;
    b=1
    rozdil_bez_0=rozdil(rozdil~=0);
    
    for i=2:size(rozdil_bez_0,2)
        if rozdil_bez_0(i-1)*rozdil_bez_0(i)<0 then
            b=b+1;
        end
    end
    T=(2*b-(n-2))/sqrt(n-1);
    [P,Q]=cdfnor("PQ",T,0,1);
    z_alpha=cdfnor("X",0,1,alpha,1-alpha);
    p_hodnota=P;
endfunction

//pearsonův test - test nezávislosti výběrů
function [p_hodnota,T,t_alpha]=pearson_test(X,Y,alpha) 
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny 
    //t_alpha ... kritická hodnota
    //X ... náhodný výběr č. 1
    //Y ... náhodný výběr č. 2
    //alpha ... hladina významnosti

    if argn(2)==2 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    X=X(:)';
    Y=Y(:)';
    cov=kovariance(X,Y);
    r=cov/sqrt(variance(X)*variance(Y));
    n=size(X,2);
    T=r/sqrt((1-r^2)/(n-2));
    Df=n-2;
    [P,Q]=cdft("PQ",T,Df)
    p_hodnota=2*min(P,Q)
    Alpha=alpha/2;
    t_alpha=cdft("T",Df,1-Alpha,Alpha);
endfunction

//spearmanův_test - test nezávislosti výběrů
function [p_hodnota,T,t_alpha]=spearman_test(X,Y,alpha) 
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny 
    //t_alpha ... kritická hodnota
    //X ... náhodný výběr č. 1
    //Y ... náhodný výběr č. 2
    //alpha ... hladina významnosti
    if argn(2)==2 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    X=X(:)';
    Y=Y(:)';

    n=size(X,2);
    z=[X;Y];
    Z=gsort(z,'lc',"i");
    X=Z(1,:); Y=Z(2,:);
    usporadane_Y=gsort(Y,"c","i");
    x=1:n;
    for i=1:n
        y(1,i)=find(Y(1,i)==usporadane_Y,1);
    end
    Df=n-2;
    Alpha=alpha/2;
    t_alpha=cdft("T",Df,1-Alpha,Alpha);   
    S=sum((x-y).^2);
    if S==0 then
        disp("Korelační koeficient je roven 1")
        disp("Hypotézu zamítáme")
        T=%inf
        p_hodnota=0
    else
        r_s=1-(6/(n*(n^2-1))*S);
        T=r_s*sqrt((n-2)/(1-r_s^2));
        [P,Q]=cdft("PQ",T,Df)
        p_hodnota=2*min(P,Q)
    end    
endfunction

function [p_hodnota,T]=KS_test(alpha,x,rozdeleni,varargin)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny 
    //alpha ... hladina významnosti 
    //X ... náhodný výběr č. 1
    //rozdeleni ... očekávaný typ rozdělení
    //parametry ... parametry rozdělení 
    //rozdělení + parametry
    //   'normalni',střední hodnota,rozptyl 
    //   'studentovo',počet stupňů volnosti
    //   'chikvadrat',počet stupňů volnosti
    
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    parametr=varargin;
    if size(x,1)>size(x,2) then //x bude radkovy vektor
        x=x';
    end
    if size(x,1)~=1 then //test,zda je x radkovy vektor
        error ('ks_test: x must be a vector')
    end
    n=size(x,2)
    sort_x=gsort(x,'c','i')
    select rozdeleni
    case 'normalni' then
        f=['cdfnor('"PQ'",sort_x,parametr(1)*ones(x),sqrt(parametr(2))*ones(x))'];
        z=evstr(f)
    case 'studentovo'
        f=['cdft('"PQ'",sort_x,parametr(1)*ones(x))'];
        z=evstr(f)
    case 'chikvadrat'
        f=['cdfchi('"PQ'",sort_x,parametr(1)*ones(x))'];
        z=evstr(f)
    end
    strana='o';
    if strana=='o'
        T   = sqrt (n) * max (max ([abs(z - (0:(n-1))/n); abs(z - (1:n)/n)]));
        p_hodnota = 1 - pks(T); // (strcmp (alt, '>'))
    elseif strana=='p'
        T = sqrt (n) * max (max ([z - (0:(n-1))/n; z - (1:n)/n]));
        p_hodnota = exp (- 2 * T^2);
    end 
endfunction
