//test hypotez
//z_test
function [p_hodnota,T,z_alpha]=z_test(Mu0,stredni_hodnota,rozptyl,n,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //Mu0 ... předpokládaná střední hodnota
    //stredni_hodnota ... střední hodnota výběru
    //rozptyl ... rozptyl souboru (musí být zadán)
    //n ... počet prvků výběru    
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==5 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end

    T=(stredni_hodnota-Mu0)/(sqrt(rozptyl)/sqrt(n));
//    [P,Q]=cdfnor("PQ",T,stredni_hodnota,sqrt(rozptyl));
    [P,Q]=cdfnor("PQ",T,0,1);
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;
        z_alpha=cdfnor("X",0,1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        z_alpha=cdfnor("X",0,1,1-alpha,alpha);
    case 'l' then
        z_alpha=cdfnor("X",0,1,alpha,1-alpha);
        p_hodnota=P;
    end
endfunction

//t test
function [p_hodnota,T,t_alpha]=t_test(Mu0,stredni_hodnota,rozptyl,n,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny
    //t_alpha ... kritická hodnota
    //Mu0 ... předpokládaná střední hodnota
    //stredni_hodnota ... střední hodnota výběru
    //rozptyl ... rozptyl výběru
    //n ... počet prvků výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==5 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    T=(stredni_hodnota-Mu0)/(sqrt(rozptyl)/sqrt(n));
    [P,Q]=cdft("PQ",T,n-1)
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q)
        Alpha=alpha/2;
        t_alpha=cdft("T",n-1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        t_alpha=cdft("T",n-1,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        t_alpha=cdft("T",n-1,alpha,1-alpha);
    end
endfunction

//test podilu
function [p_hodnota,T,z_alpha]=prop_test(p0,p,n,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //p0 ... předpokládaná hodnota pravděpodobnosti
    //p ... pravděpodobnost úspěchu nebo počet úspěchů ve výběru
    //n ... pocet prvků výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if p>1 then
        prav=p/n;
    else
        prav=p;
    end
    if argn(2)==4 then
        alpha=0.05;
    end
    
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    T=(prav-p0)/sqrt(p0*(1-p0)/n)
    [P,Q]=cdfnor("PQ",T,0,1);
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;
        z_alpha=cdfnor("X",0,1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        z_alpha=cdfnor("X",0,1,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        z_alpha=cdfnor("X",0,1,alpha,1-alpha);
    end
endfunction

//test rozptylu
function [p_hodnota,T,chi_alpha]=var_test(sigma0,rozptyl,n,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny    
    //sigma0 ... předpokládaná hodnota rozptylu
    //n ... počet prvků výběru
    //rozptyl ... rozptyl výběru
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==4 then
        alpha=0.05;        
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    T=((n-1)/sigma0)*rozptyl;
    [P,Q]=cdfchi("PQ",T,n-1)
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;            
        hm_chi_alpha_2=cdfchi("X",n-1,1-Alpha,Alpha);
        dm_chi_alpha_2=cdfchi("X",n-1,Alpha,1-Alpha);
        chi_alpha=[dm_chi_alpha_2,hm_chi_alpha_2]
    case 'p' then
        p_hodnota=Q;
        hm_chi_alpha=cdfchi("X",n-1,1-alpha,alpha);
        chi_alpha=[0,hm_chi_alpha]
    case 'l' then
        p_hodnota=P;
        dm_chi_alpha=cdfchi("X",n-1,alpha,1-alpha);
        chi_alpha=[dm_chi_alpha,%inf]
    end  
endfunction



  
