//parametricke testy pro dva vybery
function [p_hodnota,T,z_alpha]=z_test_2(stredni_hodnota_1,rozptyl_1,n1,stredni_hodnota_2,rozptyl_2,n2,strana,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //stredni_hodnota_1 ... střední hodnota výběru č. 1
    //rozptyl_1 ... rozptyl souboru č. 1
    //n1 .. počet prvků výběru
    //stredni_hodnota_2 ... střední hodnota výběru č. 2
    //rozptyl_2 ... rozptyl souboru č. 2
    //n2 ... počet prvků výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==7 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    T=(stredni_hodnota_1-stredni_hodnota_2)/sqrt((rozptyl_1/n1)+(rozptyl_2/n2));
    [P,Q]=cdfnor("PQ",T,0,1);
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;
        z_alpha=cdfnor("X",0,1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        z_alpha=cdfnor("X",0,1,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        z_alpha=cdfnor("X",0,1,alpha,1-alpha);
    end
endfunction

//t test sdruzeny
function [p_hodnota,T,t_alpha]=t_test_2s(stredni_hodnota_1,rozptyl_1,n1,stredni_hodnota_2,rozptyl_2, n2,strana,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //stredni_hodnota_1 ... střední hodnota výběru č. 1
    //rozptyl_1 ... rozptyl výběru č. 1
    //n1 .. počet prvků výběru
    //stredni_hodnota_2 ... střední hodnota výběru č. 2
    //rozptyl_2 ... rozptyl výběru č. 2
    //n2 ... počet prvků výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==7 then
        alpha=0.05;       
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    Df=n1+n2-2;
    sp=((n1-1)*rozptyl_1+(n2-1)*rozptyl_2)/(Df);   
    T=(stredni_hodnota_1-stredni_hodnota_2)/(sqrt(sp)*sqrt((1/n1)+(1/n2)));
    [P,Q]=cdft("PQ",T,Df)
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q)
        Alpha=alpha/2;
        t_alpha=cdft("T",Df,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        t_alpha=cdft("T",Df,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        t_alpha=cdft("T",Df,alpha,1-alpha);
    end
endfunction

//t test nesdruzeny
function [p_hodnota,T,t_alpha]=t_test_2n(stredni_hodnota_1,rozptyl_1,n1,stredni_hodnota_2,rozptyl_2, n2,strana,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //stredni_hodnota_1 ... střední hodnota výběru č. 1
    //rozptyl_1 ... rozptyl výběru č. 1
    //n1 .. počet prvků výběru
    //stredni_hodnota_2 ... střední hodnota výběru č. 2
    //rozptyl_2 ... rozptyl výběru č. 2
    //n2 ... počet prvků výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti
    if argn(2)==7 then
        alpha=0.05;       
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    
    R1_n1=rozptyl_1/n1;
    R2_n2=rozptyl_2/n2;   
    T=(stredni_hodnota_1-stredni_hodnota_2)/(sqrt(R1_n1+R2_n2));
    Df=round((R1_n1+R2_n2)^2/((R1_n1^2/(n1-1))+(R2_n2^2/(n2-1))));
    [P,Q]=cdft("PQ",T,Df)
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q)
        Alpha=alpha/2;
        t_alpha=cdft("T",Df,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        t_alpha=cdft("T",Df,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        t_alpha=cdft("T",Df,alpha,1-alpha);
    end
endfunction

//t test parovy
function [p_hodnota,T,t_alpha]=t_test_2p(vyber1,vyber2,strana,alpha)
    //p_hodnota ... p-hodnota
    //T ... statistika náhodné veličiny
    //t_alpha ... kritická hodnota
    //alpha ... hladina významnosti
    //vyber1 ... prvky výběru č. 1
    //vyber2 ... prvky výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    vektor1=vyber1(:)';
    vektor2=vyber2(:)';
    if argn(2)==3 then
        alpha=0.05;       
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    n=max(size(vektor1));
    x_d=sum(vektor1-vektor2)/n;
    s_d=sqrt((sum((vektor1-vektor2)^2)/n)-x_d^2);
    T=(x_d/s_d)*sqrt(n-1);
    Df=n-1;
    [P,Q]=cdft("PQ",T,Df)
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q)
        Alpha=alpha/2;
        t_alpha=cdft("T",Df,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        t_alpha=cdft("T",Df,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        t_alpha=cdft("T",Df,alpha,1-alpha);
    end
endfunction

//test podilu
function [p_hodnota,T,z_alpha]=prop_test_2(p1,n1,p2,n2,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny
    //z_alpha ... kritická hodnota
    //p1 ... pravděpodobnost úspěchu nebo počet úspěchů ve výběru č. 1
    //n1 ... počet prvků výběru č. 1
    //p2 ... pravděpodobnost úspěchu nebo počet úspěchů ve výběru č. 2
    //n2 ... pocet prvků výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti

    if p1>1 then
        prav1=p1/n1;
    else
        prav1=p1;
    end
    if p2>1 then
        prav2=p2/n2;
    else
        prav2=p2;
    end
    if argn(2)==5 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end


    pp=(prav1*n1+prav2*n2)/(n1+n2);
    T=(prav1-prav2)/(sqrt(pp*(1-pp))*sqrt(1/n1+1/n2));
    [P,Q]=cdfnor("PQ",T,0,1);
    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;
        z_alpha=cdfnor("X",0,1,1-Alpha,Alpha);
    case 'p' then
        p_hodnota=Q;
        z_alpha=cdfnor("X",0,1,1-alpha,alpha);
    case 'l' then
        p_hodnota=P;
        z_alpha=cdfnor("X",0,1,alpha,1-alpha);
    end
endfunction

//test dvou rozptylů
function [p_hodnota,T,f_alpha]=var_test_2(Rozptyl_S1,n1,Rozptyl_S2,n2,strana,alpha)
    //p_hodnota... p-hodnota
    //T ... statistika náhodné veličiny
    //Rozptyl_S1 ... výběrový rozptyl z výběru č. 1
    //n1 ... počet prvků výběru č. 1
    //Rozptyl_S2 ... výběrový rozptyl z výběru č. 2
    //n1 ... počet prvků výběru č. 2
    //strana ... typ IS ('l'=levostranný, 'p'=pravostranný, 'o' oboustranný)
    //alpha ... hladina významnosti

    if argn(2)==5 then
        alpha=0.05;
    end
    if alpha>0.5 then
        disp('alpha je kritická hodnota, musí být tedy < 0.5');
        return
    end
    if Rozptyl_S1>Rozptyl_S2 then
        T=Rozptyl_S1/Rozptyl_S2;
    else
        T=Rozptyl_S2/Rozptyl_S1;
    end
    Df1=n1-1;
    Df2=n2-1;
    [P,Q]=cdff("PQ",T,Df1,Df2);

    select strana
    case 'o' then
        p_hodnota=2*min(P,Q);
        Alpha=alpha/2;            
        hm_f_alpha_2=cdff("F",Df1,Df2,1-Alpha,Alpha);
        dm_f_alpha_2=cdff("F",Df1,Df2,Alpha,1-Alpha);
        f_alpha=[dm_f_alpha_2,hm_f_alpha_2]
    case 'p' then
        p_hodnota=Q;
        hm_f_alpha=cdff("F",Df1,Df2,1-alpha,alpha);
        f_alpha=[0,hm_f_alpha]
    case 'l' then
        p_hodnota=P;
        dm_f_alpha=cdff("F",Df1,Df2,alpha,1-alpha);
        f_alpha=[dm_f_alpha,%inf]
    end  
endfunction
