//regrese
//lineární regrese
function p=lin_reg(x,y)
    //p ... hodnoty parametrů [b1 b0]
    //x ... nezávisle proměnná
    //y ... závisle proměnná
    x=x(:)';
    y=y(:)';
    n=length(x);
    if length(y) ~= n, 
        disp('Vektory x a y musi mit stejnou delku');
    end
    x=matrix(x,n,1);
    y=matrix(y,n,1);
    D=[y x ones(n,1)];
    V=D'*D;
    m=size(V,2);
    Vyf=V(2:m,1);
    Vf=V(2:m,2:m);
    p=inv(Vf)*Vyf;
endfunction  

//lineární predikce
function yp=lin_pred(x,p)
    //yp ... predikce závisle proměnné
    //x ... nezávisle proměnná
    //p ... hodnoty parametrů [b1 b0]
    x=x(:)';
    m=length(p);
    yp=p(1)*x+p(2);
endfunction 

//vícenásobná lineární regrese
function p=lin_reg_n(x,y)
    //p ... hodnoty parametrů [bn bn-1 ... b1 b0]
    //x ... nezávisle proměnná
    //y ... závisle proměnná
    if size(x,1)<size(x,2) then
        x=x';
    end
    y=y(:);
    n=size(y,1);
    if size(x,1) ~= n 
        disp(' x a y musi mit stejný pocet vzorku');
        return
    end
    D=[y x ones(n,1)];
    V=D'*D;
    p=inv(V(2:$,2:$))*V(2:$,1);
    //inv(x1'*x1)*x1'*y;
endfunction 

//vícenásobná lineární predikce
function yp=lin_pred_n(x,p)
    //yp ... predikce závisle proměnné
    //x ... nezávisle proměnná
    //p ... hodnoty parametrů [bn bn-1 ... b1 b0]
    if size(x,1)<size(x,2) then
        x=x';
    end
    k=length(p);
    p=p(:);
    [m,n]=size(x);
    if min(m,n)==1 then
        if m>n then
            x=x'; 
        end
        if n ~= k-1 then
            disp('Matice x ma spatne rozmery');
        end
    else
        if m<n then
            x=x'
        end
    end
    x1=[x ones(size(x,1),1)];
    yp=x1*p;
    yp=yp(:)';
endfunction  

//exponenciální regrese
function p=exp_reg(x,y)
    //p ... hodnoty parametrů [bn bn-1 ... b1 b0]
    //x ... nezávisle proměnná
    //y ... závisle proměnná
    n=max(size(x));
    if max(size(y)) ~= n, 
        disp('Vektory x a y musi mit stejnou delku');
    end
    x=matrix(x,n,1);
    y=matrix(y,n,1);
    x=matrix(x,n,1);
    if sum(y<0)>0
        disp('ERROR in exp_reg: There is a negative element in y!');
        return
    end
    D=[log(y) x ones(n,1)];
    V=D'*D;
    m=max(size(V));
    Vyf=V(2:m,1);
    Vf=V(2:m,2:m);
    p=inv(Vf)*Vyf;
    p(2)=exp(p(2));
endfunction  

//exponenciální predikce
function yp=exp_pred(x,p)
    //yp ... predikce závisle proměnné
    //x ... nezávisle proměnná
    //p ... hodnoty parametrů [b1 b0]
    m=length(p);
    yp=exp(p(1)*x)*p(2);
endfunction  

//polynomiální regrese
function p=pol_reg(x,y,k)
    //p ... hodnoty parametrů [bn bn-1 ... b1 b0]
    //x ... nezávisle proměnná
    //y ... závisle proměnná
    //k ... stupeň regresního polynomu 
    n=length(x);
    if length(y) ~= n, 
        disp('Vektory x a y musi mit stejnou delku');
    end
    x=matrix(x,n,1);
    y=matrix(y,n,1);
    D=y;
    for i=1:k
        kk=k-i+1;
        D=[D x.^kk];
    end
    D=[D ones(n,1)];
    V=D'*D;
    m=max(size(V));
    Vyf=V(2:m,1);
    Vf=V(2:m,2:m);
    p=inv(Vf)*Vyf;
endfunction 

//polynomiální predikce
function yp=pol_pred(x,p)
    //yp ... predikce závisle proměnné
    //x ... nezávisle proměnná
    //p ... hodnoty parametrů [b1 b0]
    m=max(size(p));
    yp=zeros(size(x,1),size(x,2));
    for i=1:m
        yp=yp.*x+p(i);
    end
endfunction




